/*
 * ----------------------------------------------------------------
 *
 * Header for Intel Hex Record parser
 *
 * (C) 2005  Lightmaze Solutions AG
 *   Author: Jochen Karrer
 *
 * Status:
 *      Working, but Segmented address records are missing
 *  
 *  This program is free software; you can distribute it and/or modify it
 *  under the terms of the GNU General Public License (Version 2) as
 *  published by the Free Software Foundation.
 *  
 *  This program is distributed in the hope it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 *  for more details.
 *  
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
 * 
 * ----------------------------------------------------------------
 */

typedef int XY_IHexDataHandler(uint32_t addr,uint8_t *buf,int len,void *clientData);
int64_t XY_LoadIHexFile(const char *filename, XY_IHexDataHandler *cb,void *clientData);
